<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:tei="http://www.tei-c.org/ns/1.0"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" exclude-result-prefixes="xs xd" version="2.0">

    <!-- Wurzeltemplate. Stellt rudimentäre html-Struktur bereit -->
    <xsl:template match="/">
        <html>
            <head>
                <title>KritEdit-Beispieltransformation</title>
            </head>
            <body>
                <xsl:apply-templates/>
            </body>
        </html>
    </xsl:template>

    <!-- Wurzelelement tei:TEI. Wichtig: der Namespace tei muss 
        a) im Prolog definiert sein (vgl. Zeile 2, das Attribut xmlns:tei="http://www.tei-c.org/ns/1.0" 
        b) in den match-Attributen explizit angegeben werden-->
    <xsl:template match="tei:TEI">
        <xsl:apply-templates/>
    </xsl:template>

    <!-- leeres Template für den teiHeader, unterdrückt die Ausgabe -->
    <xsl:template match="tei:teiHeader"/>


    <!-- Templates für tei:head -->
    <xsl:template match="tei:head">
        <h1>
            <xsl:value-of select="text()"/>
        </h1>
    </xsl:template>

    <!-- Templates für tei:head mit attribut type="subtitle". Wichtig: XSL wendet immer das speziellere template vor dem allgemeineren an. 
        Hier wird also getestet, ob das das head-Element ein type-Attribut "subtitle" hat. Falls ja, wird dieses Template angewendet,
        falls nein, das allgemeine template für head -->
    <xsl:template match="tei:head[@type='subtitle']">
        <h2>
            <xsl:value-of select="text()"/>
        </h2>
    </xsl:template>

    <!-- template für Gedichtzeilen -->
    <xsl:template match="tei:l">

        <!-- stelle vor jeder Zeile einen 20 Pixel breiten Block bereit. Die Angaben im style-Attribut sind CSS-Angaben. 
                Normalerweise würde man diese ggf. in  eine externe css-Datei auslagern, die mit der html-Datei verknüpft wird -->
        <span class="linenumber" style="display:inline-block; width:20px; text-align:right;">
            <!-- Test: ist die Zeilenzahl durch 5 teilbar, nur dann wird sie ausgegeben -->
            <xsl:if test="@n mod 5 = 0">
                <xsl:value-of select="@n"/>
            </xsl:if>
        </span>
        <xsl:text>   </xsl:text>

        <!-- Sprungmarke, damit von den Anmerkungen zu dieser Zeile gesprungen werden kann -->
        <a name="line{@n}"/>

        <!-- hier wird der Inhalt der Zeile eingefügt -->
        <xsl:apply-templates/>

        <!-- nach der Zeile werden hochgestellt Links auf den Apparat oder auf die Anmerkungen eingefügt, sofern es entsprechende Anmerkungen gibt -->
        <xsl:if test="//tei:div[@type='critNotes']/tei:note/tei:app/@loc=@n">
            <sup>
                <a href="#crit{@n}"> App</a>
            </sup>
        </xsl:if>
        <xsl:if test="//tei:div[@type='explNotes']/tei:note/@target=@n">
            <sup>
                <a href="#expl{@n}"> Anm</a>
            </sup>
        </xsl:if>
        <br/>
    </xsl:template>

    <xsl:template match="tei:div">
        
            <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:div[@type='critNotes']/tei:note">

        <span style="display:inline-block; width:20px; text-align:right;">
            <xsl:if test="tei:app/@loc">
                <a name="crit{tei:app/@loc}" href="#line{tei:app/@loc}">
                    <xsl:value-of select="tei:app/@loc"/>
                </a>
            </xsl:if>
            <xsl:if test="@target">
                <a name="crit{@target}" href="#line{@target}">
                    <xsl:value-of select="@target"/>
                </a>
            </xsl:if>
            <xsl:text> </xsl:text>
        </span>
        <!-- gib alles weitere aus -->
        <xsl:apply-templates/>
        <!-- mache einen Zeilenumbruch -->
        <br/>
    </xsl:template>

    <!-- Template für Lemma, setzt einfach nur hinter das Lemma eine eckige Klammer -->
    <xsl:template match="tei:lem">
        <xsl:value-of select="."/>
        <xsl:text>] </xsl:text>
    </xsl:template>

    <!-- template für die Readings, gibt den Elementinhalt (die Variante) kursiv aus und setzt in Klammern dahinter die in @wit kodierten Textzeugen -->
    <xsl:template match="tei:rdg">

        <!-- Lesart -->
        <i>
            <xsl:apply-templates/>
        </i>

        <!-- Textzeugen -->
        <xsl:text> (</xsl:text>
        <!-- replace-Funktion, lies: Ersetze im Inhalt von @wit alle Zeichen, die entweder # oder Leerzeichen sind durch garnichts -->
        <!-- Ist nur dazu da, die im @wit-Attribut kodierten *Referenzen* auf die Witnesslist besser lesbar zu machen -->
        <!-- theoretisch könnte man hier auch von den Siglen der Textzeugen zu einer Liste der Textzeugen verlinken -->
        <xsl:value-of select="replace(@wit,  '[# ]', '')"/>
        <xsl:text>) </xsl:text>
    </xsl:template>


    <!-- Template für die notes, die in der division explNotes stehen der Teil [@type='explNotes'] ist ein "Filter" 
        (lies: "das template gilt nur für note-Elemente, die im tei:div-Element desses type-Attribut gleich "explNotes" ist -->
    <xsl:template match="tei:div[@type='explNotes']/tei:note">

        <xsl:if test="@target">
            <span style="display:inline-block; width:20px; text-align:right;">
                <a name="expl{@target}" href="#line{@target}">
                    <xsl:value-of select="@target"/>
                </a>
            </span>
            <xsl:text> </xsl:text>
        </xsl:if>

        <xsl:apply-templates/>
        <br/>
    </xsl:template>

</xsl:stylesheet>
